pub trait TrackerSensitivity<SolveState: Interpolatable, Rx>: TrackingDevice<SolveState>where
Self: Sized,
DefaultAllocator: Allocator<SolveState::Size> + Allocator<SolveState::VecLength> + Allocator<SolveState::Size, SolveState::Size>,{
// Required method
fn h_tilde<M: DimName>(
&self,
msr: &Measurement,
msr_types: &IndexSet<MeasurementType>,
rx: &Rx,
almanac: Arc<Almanac>,
) -> Result<OMatrix<f64, M, SolveState::Size>, ODError>
where DefaultAllocator: Allocator<M> + Allocator<M, SolveState::Size>;
}Expand description
Trait required to build a triplet of a solve-for state, a receiver, and a transmitter.
Required Methods
Sourcefn h_tilde<M: DimName>(
&self,
msr: &Measurement,
msr_types: &IndexSet<MeasurementType>,
rx: &Rx,
almanac: Arc<Almanac>,
) -> Result<OMatrix<f64, M, SolveState::Size>, ODError>
fn h_tilde<M: DimName>( &self, msr: &Measurement, msr_types: &IndexSet<MeasurementType>, rx: &Rx, almanac: Arc<Almanac>, ) -> Result<OMatrix<f64, M, SolveState::Size>, ODError>
Returns the sensitivity matrix of size MxS where M is the number of simultaneous measurements and S is the size of the state being solved for.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".